==> chaosmesh-model-5.2.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/JVMExceptionSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class JVMExceptionSpecFluentImpl<A extends JVMExceptionSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements JVMExceptionSpecFluent<A> {

    private Boolean after;
    private String classname;
    private String exception;
    private String message;
    private String methodname;

    public JVMExceptionSpecFluentImpl() {
    }

    public JVMExceptionSpecFluentImpl(JVMExceptionSpec instance) {
        this.withAfter(instance.getAfter()); 
        this.withClassname(instance.getClassname()); 
        this.withException(instance.getException()); 
        this.withMessage(instance.getMessage()); 
        this.withMethodname(instance.getMethodname()); 
    }

    public Boolean isAfter() {
        return this.after;
    }

    public A withAfter(Boolean after) {
        this.after=after; return (A) this;
    }

    public Boolean hasAfter() {
        return this.after != null;
    }

    public A withNewAfter(String arg1) {
        return (A)withAfter(new Boolean(arg1));
    }

    public A withNewAfter(boolean arg1) {
        return (A)withAfter(new Boolean(arg1));
    }

    public String getClassname() {
        return this.classname;
    }

    public A withClassname(String classname) {
        this.classname=classname; return (A) this;
    }

    public Boolean hasClassname() {
        return this.classname != null;
    }

    public A withNewClassname(String arg1) {
        return (A)withClassname(new String(arg1));
    }

    public A withNewClassname(StringBuilder arg1) {
        return (A)withClassname(new String(arg1));
    }

    public A withNewClassname(StringBuffer arg1) {
        return (A)withClassname(new String(arg1));
    }

    public String getException() {
        return this.exception;
    }

    public A withException(String exception) {
        this.exception=exception; return (A) this;
    }

    public Boolean hasException() {
        return this.exception != null;
    }

    public A withNewException(String arg1) {
        return (A)withException(new String(arg1));
    }

    public A withNewException(StringBuilder arg1) {
        return (A)withException(new String(arg1));
    }

    public A withNewException(StringBuffer arg1) {
        return (A)withException(new String(arg1));
    }

    public String getMessage() {
        return this.message;
    }

    public A withMessage(String message) {
        this.message=message; return (A) this;
    }

    public Boolean hasMessage() {
        return this.message != null;
    }

    public A withNewMessage(String arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(StringBuilder arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(StringBuffer arg1) {
        return (A)withMessage(new String(arg1));
    }

    public String getMethodname() {
        return this.methodname;
    }

    public A withMethodname(String methodname) {
        this.methodname=methodname; return (A) this;
    }

    public Boolean hasMethodname() {
        return this.methodname != null;
    }

    public A withNewMethodname(String arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public A withNewMethodname(StringBuilder arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public A withNewMethodname(StringBuffer arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        JVMExceptionSpecFluentImpl that = (JVMExceptionSpecFluentImpl) o;
        if (after != null ? !after.equals(that.after) :that.after != null) return false;
        if (classname != null ? !classname.equals(that.classname) :that.classname != null) return false;
        if (exception != null ? !exception.equals(that.exception) :that.exception != null) return false;
        if (message != null ? !message.equals(that.message) :that.message != null) return false;
        if (methodname != null ? !methodname.equals(that.methodname) :that.methodname != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(after,  classname,  exception,  message,  methodname,  super.hashCode());
    }

}

==> chaosmesh-model-5.3.2-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/JVMExceptionSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class JVMExceptionSpecFluentImpl<A extends JVMExceptionSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements JVMExceptionSpecFluent<A> {

    private Boolean after;
    private String classname;
    private String exception;
    private String message;
    private String methodname;

    public JVMExceptionSpecFluentImpl() {
    }

    public JVMExceptionSpecFluentImpl(JVMExceptionSpec instance) {
        this.withAfter(instance.getAfter()); 
        this.withClassname(instance.getClassname()); 
        this.withException(instance.getException()); 
        this.withMessage(instance.getMessage()); 
        this.withMethodname(instance.getMethodname()); 
    }

    public Boolean getAfter() {
        return this.after;
    }

    public A withAfter(Boolean after) {
        this.after=after; return (A) this;
    }

    public Boolean hasAfter() {
        return this.after != null;
    }

    public A withNewAfter(String arg1) {
        return (A)withAfter(new Boolean(arg1));
    }

    public A withNewAfter(boolean arg1) {
        return (A)withAfter(new Boolean(arg1));
    }

    public String getClassname() {
        return this.classname;
    }

    public A withClassname(String classname) {
        this.classname=classname; return (A) this;
    }

    public Boolean hasClassname() {
        return this.classname != null;
    }

    public A withNewClassname(StringBuilder arg1) {
        return (A)withClassname(new String(arg1));
    }

    public A withNewClassname(int[] arg1,int arg2,int arg3) {
        return (A)withClassname(new String(arg1, arg2, arg3));
    }

    public A withNewClassname(char[] arg1) {
        return (A)withClassname(new String(arg1));
    }

    public A withNewClassname(StringBuffer arg1) {
        return (A)withClassname(new String(arg1));
    }

    public A withNewClassname(byte[] arg1,int arg2) {
        return (A)withClassname(new String(arg1, arg2));
    }

    public A withNewClassname(byte[] arg1) {
        return (A)withClassname(new String(arg1));
    }

    public A withNewClassname(char[] arg1,int arg2,int arg3) {
        return (A)withClassname(new String(arg1, arg2, arg3));
    }

    public A withNewClassname(byte[] arg1,int arg2,int arg3) {
        return (A)withClassname(new String(arg1, arg2, arg3));
    }

    public A withNewClassname(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withClassname(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewClassname(String arg1) {
        return (A)withClassname(new String(arg1));
    }

    public String getException() {
        return this.exception;
    }

    public A withException(String exception) {
        this.exception=exception; return (A) this;
    }

    public Boolean hasException() {
        return this.exception != null;
    }

    public A withNewException(StringBuilder arg1) {
        return (A)withException(new String(arg1));
    }

    public A withNewException(int[] arg1,int arg2,int arg3) {
        return (A)withException(new String(arg1, arg2, arg3));
    }

    public A withNewException(char[] arg1) {
        return (A)withException(new String(arg1));
    }

    public A withNewException(StringBuffer arg1) {
        return (A)withException(new String(arg1));
    }

    public A withNewException(byte[] arg1,int arg2) {
        return (A)withException(new String(arg1, arg2));
    }

    public A withNewException(byte[] arg1) {
        return (A)withException(new String(arg1));
    }

    public A withNewException(char[] arg1,int arg2,int arg3) {
        return (A)withException(new String(arg1, arg2, arg3));
    }

    public A withNewException(byte[] arg1,int arg2,int arg3) {
        return (A)withException(new String(arg1, arg2, arg3));
    }

    public A withNewException(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withException(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewException(String arg1) {
        return (A)withException(new String(arg1));
    }

    public String getMessage() {
        return this.message;
    }

    public A withMessage(String message) {
        this.message=message; return (A) this;
    }

    public Boolean hasMessage() {
        return this.message != null;
    }

    public A withNewMessage(StringBuilder arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(int[] arg1,int arg2,int arg3) {
        return (A)withMessage(new String(arg1, arg2, arg3));
    }

    public A withNewMessage(char[] arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(StringBuffer arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(byte[] arg1,int arg2) {
        return (A)withMessage(new String(arg1, arg2));
    }

    public A withNewMessage(byte[] arg1) {
        return (A)withMessage(new String(arg1));
    }

    public A withNewMessage(char[] arg1,int arg2,int arg3) {
        return (A)withMessage(new String(arg1, arg2, arg3));
    }

    public A withNewMessage(byte[] arg1,int arg2,int arg3) {
        return (A)withMessage(new String(arg1, arg2, arg3));
    }

    public A withNewMessage(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withMessage(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewMessage(String arg1) {
        return (A)withMessage(new String(arg1));
    }

    public String getMethodname() {
        return this.methodname;
    }

    public A withMethodname(String methodname) {
        this.methodname=methodname; return (A) this;
    }

    public Boolean hasMethodname() {
        return this.methodname != null;
    }

    public A withNewMethodname(StringBuilder arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public A withNewMethodname(int[] arg1,int arg2,int arg3) {
        return (A)withMethodname(new String(arg1, arg2, arg3));
    }

    public A withNewMethodname(char[] arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public A withNewMethodname(StringBuffer arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public A withNewMethodname(byte[] arg1,int arg2) {
        return (A)withMethodname(new String(arg1, arg2));
    }

    public A withNewMethodname(byte[] arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public A withNewMethodname(char[] arg1,int arg2,int arg3) {
        return (A)withMethodname(new String(arg1, arg2, arg3));
    }

    public A withNewMethodname(byte[] arg1,int arg2,int arg3) {
        return (A)withMethodname(new String(arg1, arg2, arg3));
    }

    public A withNewMethodname(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withMethodname(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewMethodname(String arg1) {
        return (A)withMethodname(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        JVMExceptionSpecFluentImpl that = (JVMExceptionSpecFluentImpl) o;
        if (after != null ? !after.equals(that.after) :that.after != null) return false;
        if (classname != null ? !classname.equals(that.classname) :that.classname != null) return false;
        if (exception != null ? !exception.equals(that.exception) :that.exception != null) return false;
        if (message != null ? !message.equals(that.message) :that.message != null) return false;
        if (methodname != null ? !methodname.equals(that.methodname) :that.methodname != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(after,  classname,  exception,  message,  methodname,  super.hashCode());
    }

}
